//
// Test7Seg.cxx 2006-01-23 z_hossain
//
// Test of seven segment widget for the Fast Light Tool Kit (FLTK).
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//

#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Input.H>
#include <FL/Fl_Value_Slider.H>
#include <stdio.h>

#include "Fl_7Seg.H"

Fl_Input *txt_value = 0;
Fl_Value_Slider *sl_thick = 0;
Fl_Value_Slider *sl_value = 0;
Fl_Value_Slider *sl_gap = 0;
Fl_Value_Slider *sl_col = 0;
Fl_7Seg *seg_big = 0;
Fl_7Seg *seg_small = 0;
Fl_Double_Window* make_window();

static int COLOR[] = {
	56, 88, 63, 95, 216, 248, 223, 72
};

static void cb_txt_value(Fl_Input* in, void*) {
	seg_small->value(in->value());
	in->value(seg_small->value());//get what is actual
}

static void cb_sl_thick(Fl_Value_Slider*, void*) {
	seg_big->thickness((int)sl_thick->value());
}

static void cb_sl_value(Fl_Value_Slider*, void*) {
	static char buf[10];
	sprintf(buf, "%d", (int)sl_value->value());
	seg_big->value(buf);
}

static void cb_sl_gap(Fl_Value_Slider*, void*) {
	seg_big->segment_gap((int)sl_gap->value());
}

static void cb_sl_col(Fl_Value_Slider*, void*) {
	seg_big->segment_color((Fl_Color)COLOR[int(sl_col->value())]);
}

int main(int ac,char **av) {
	Fl_Double_Window* w;
	{ Fl_Double_Window* o = new Fl_Double_Window(450, 305);
		w = o;
		{ Fl_7Seg* o = seg_big = new Fl_7Seg(20, 25, 255, 267);
			o->box(FL_ENGRAVED_FRAME);
			//o->deactivate(); 															//support activate/deactivate
		}
		{ Fl_7Seg* o = seg_small = new Fl_7Seg(285, 25, 135, 35);
			o->box(FL_EMBOSSED_FRAME);
			//o->dot_len(o->unit_h() / 5.0);
		}
		{ Fl_Input* o = txt_value = new Fl_Input(285, 90, 135, 25, "Any Dec/Hex Value");
			o->callback((Fl_Callback*)cb_txt_value);
			o->align(FL_ALIGN_TOP_LEFT);
			o->when(FL_WHEN_ENTER_KEY);
		}
		{ Fl_Value_Slider* o = sl_thick = new Fl_Value_Slider(335, 132, 25, 158);
			o->textsize(14);
			o->range(1, 40);
			o->step(1);
			o->value(seg_big->thickness());
			o->callback((Fl_Callback*)cb_sl_thick);
			o->align(FL_ALIGN_TOP);
		}
		{ Fl_Value_Slider* o = sl_value = new Fl_Value_Slider(295, 133, 25, 157);
			o->step(0.01);
			o->textsize(14);
			o->range(0, 9);
			o->step(1);
			o->value(0);
			cb_sl_value(o, NULL);
			o->callback((Fl_Callback*)cb_sl_value);
		}
		{ Fl_Value_Slider* o = sl_gap = new Fl_Value_Slider(375, 132, 25, 158);
			o->textsize(14);
			o->range(0, 20);
			o->step(1);
			o->value(seg_big->segment_gap());
			o->callback((Fl_Callback*)cb_sl_gap);
		}
		{ Fl_Value_Slider* o = sl_col = new Fl_Value_Slider(410, 132, 25, 158);
			o->textsize(14);
			o->range(0, 7);
			o->step(1);
			o->value(0);
			o->callback((Fl_Callback*)cb_sl_col);
		}
		o->show(ac, av);
		o->end();
	}
	return Fl::run();
}
